Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Conf ¶
type Conf struct {
Name string `yaml:"name"`
Dsn string `yaml:"dsn"`
MaxOpenConn int `yaml:"maxOpenConn"`
MaxIdleConn int `yaml:"maxIdleConn"`
IgnoreRecordNotFoundError bool `yaml:"ignoreRecordNotFoundError"`
LogLevel int `yaml:"logLevel"`
}
Conf 数据库相关配置
type Model ¶
type Model struct {
ID uint64 `gorm:"primaryKey"`
CreatedAt types.Time `gorm:"index:idx_ctime"`
UpdatedAt types.Time
}
Model a basic GoLang struct which includes the following fields: ID, CreatedAt, UpdatedAt, DeletedAt It may be embedded into your model or you may build your own model without it
type User struct {
gorm.Model
}
Click to show internal directories.
Click to hide internal directories.